@@ -16,11 +16,12 @@
 #' identifier (such as "A2325807L") to get only that series. This is an alternative
 #' to specifying `cat_no`.
 #'
-#' @param path Local directory in which to save downloaded ABS time series
-#' spreadsheets. Default is "data/ABS"; this subdirectory of your working
-#' directory will be created if it does not exist. Files are saved in a subdirectory of
-#' `path`; for example, if you run `read_abs("6202.0")` your files will be in
-#' "data/ABS/6202.0".
+#' @param path Local directory in which downloaded ABS time series
+#' spreadsheets should be stored. By default, `path` takes the value set in the
+#' environment variable "R_READABS_PATH". If this variable is not set,
+#' any files downloaded by read_abs()  will be stored in a temporary directory
+#' (\code{tempdir()}). See \code{Details} below for
+#' more information.
 #'
 #' @param metadata logical. If `TRUE` (the default), a tidy data frame including
 #' ABS metadata (series name, table name, etc.) is included in the output. If
@@ -36,6 +37,20 @@
 #' @return A data frame (tibble) containing the tidied data from the ABS time
 #' series table(s).
 #'
+#' @details `read_abs()` downloads spreadsheet(s) from the ABS containing time series
+#' data. These files need to be saved somewhere on your disk. This local directory
+#' can be controlled using the `path` argument to `read_abs()`. If the `path` argument
+#' is not set, `read_abs()` will store the files in a directory set in the
+#' "R_READABS_PATH" environment variable. If this variable isn't set, files will be
+#' saved in a temporary directory.
+#'
+#' To check the value of the "R_READABS_PATH" variable, run
+#' \code{Sys.getenv("R_READABS_PATH")}. You can set the value of this variable for a
+#' single session using \code{Sys.setenv(R_READABS_PATH = <path>)}. If you would like
+#' to change this variable for all future R sessions, edit your `.Renviron` file and
+#' add \code{R_READABS_PATH = <path>} line. The easiest way to edit this file is using
+#' \code{usethis::edit_r_environ()}.
+#'
 #' @examples
 #'
 #' # Download and tidy all time series spreadsheets from the Wage Price Index (6345.0)
@@ -55,7 +70,7 @@
 read_abs <- function(cat_no = NULL,
                      tables = "all",
                      series_id = NULL,
-                     path = "data/ABS",
+                     path = Sys.getenv("R_READABS_PATH", unset = tempdir()),
                      metadata = TRUE,
                      show_progress_bars = TRUE,
                      retain_files = TRUE){
